//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTelCallInfo.cpp
 * @brief       This is the implementation file for CallInfo class.
 */


#include <FTelCallInfo.h>
#include <FBaseSysLog.h>
#include "FTel_CallInfoImpl.h"


using namespace Tizen::Base;

namespace Tizen { namespace Telephony
{
CallInfo::CallInfo(void)
	: __pCallInfoImpl(null)
{
	__pCallInfoImpl = new (std::nothrow) _CallInfoImpl();
	SysTryReturnVoidResult(NID_TEL, __pCallInfoImpl != null, E_OUT_OF_MEMORY, "[%s] Memory allocation failed.", GetErrorMessage(E_OUT_OF_MEMORY));
}

CallInfo::CallInfo(const CallInfo& callInfo)
	: __pCallInfoImpl(null)
{
	__pCallInfoImpl = new (std::nothrow) _CallInfoImpl(*callInfo.__pCallInfoImpl);
	SysTryReturnVoidResult(NID_TEL, __pCallInfoImpl != null, E_OUT_OF_MEMORY, "[%s] Memory allocation failed.", GetErrorMessage(E_OUT_OF_MEMORY));
}

CallInfo::~CallInfo(void)
{
	delete __pCallInfoImpl;
}

CallInfo&
CallInfo::operator=(const CallInfo& rhs)
{
	if (this != &rhs)
	{
    	*__pCallInfoImpl = *(rhs.__pCallInfoImpl);
	}

	return *this;
}

CallType
CallInfo::GetCallType(void) const
{
	return __pCallInfoImpl->GetCallType();
}

String
CallInfo::GetNumber(void) const
{
	return __pCallInfoImpl->GetNumber();
}

bool
CallInfo::Equals(const Object& obj) const
{
	const CallInfo* pOther = dynamic_cast<const CallInfo*>(&obj);

	if (pOther == null)
	{
    	return false;
	}

	if (pOther == this)
	{
    	return true;
	}

	return __pCallInfoImpl->Equals(*pOther->__pCallInfoImpl);
}

int
CallInfo::GetHashCode(void) const
{
	return __pCallInfoImpl->GetHashCode();
}

CallInfo::CallInfo(CallType type, const String& number)
{
	SysLog(NID_TEL,"The CallType is %d and the number is %ls", type, number.GetPointer());

	__pCallInfoImpl = new (std::nothrow) _CallInfoImpl(type, number);
	SysTryReturnVoidResult(NID_TEL, __pCallInfoImpl != null, E_OUT_OF_MEMORY, "[%s] Memory allocation failed.", GetErrorMessage(E_OUT_OF_MEMORY));
}

}} // Tizen::Telephony
