//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTelNetworkStatus.cpp
 * @brief       This is the implementation file for NetworkStatus class.
 */

#include <FTelNetworkStatus.h>
#include <FBaseSysLog.h>
#include <FSec_AccessController.h>
#include "FTel_NetworkStatusImpl.h"

using namespace Tizen::Security;

namespace Tizen { namespace Telephony
{
NetworkStatus::NetworkStatus(void)
	: __pNetworkStatusImpl(null)
{
	__pNetworkStatusImpl = new (std::nothrow) _NetworkStatusImpl();
	SysTryReturnVoidResult(NID_TEL, __pNetworkStatusImpl != null, E_OUT_OF_MEMORY, "[%s] Memory allocation failed", GetErrorMessage(E_OUT_OF_MEMORY));
}

NetworkStatus::~NetworkStatus(void)
{
	delete __pNetworkStatusImpl;
}

bool
NetworkStatus::IsRoaming(void) const
{
	ClearLastResult();

	result r = _AccessController::CheckUserPrivilege(_PRV_SYSTEMINFO, _PRV_TELEPHONY);
	SysTryReturn(NID_TEL, r == E_SUCCESS, false, E_PRIVILEGE_DENIED,
	        "[%s] The application does not have the privilege to call this method.", GetErrorMessage(E_PRIVILEGE_DENIED));

	bool isRoaming = false;

	isRoaming = __pNetworkStatusImpl->IsRoaming();

	return isRoaming;
}

bool
NetworkStatus::IsCallServiceAvailable(void) const
{
	ClearLastResult();

	result r = _AccessController::CheckUserPrivilege(_PRV_SYSTEMINFO, _PRV_TELEPHONY);
	SysTryReturn(NID_TEL, r == E_SUCCESS, false, E_PRIVILEGE_DENIED,
	        "[%s] The application does not have the privilege to call this method.", GetErrorMessage(E_PRIVILEGE_DENIED));

	bool isCallServiceAvailable = false;

	isCallServiceAvailable = __pNetworkStatusImpl->IsCallServiceAvailable();

	return isCallServiceAvailable;
}

bool
NetworkStatus::IsDataServiceAvailable(void) const
{
	ClearLastResult();

	result r = _AccessController::CheckUserPrivilege(_PRV_SYSTEMINFO, _PRV_TELEPHONY);
	SysTryReturn(NID_TEL, r == E_SUCCESS, false, E_PRIVILEGE_DENIED,
	        "[%s] The application does not have the privilege to call this method.", GetErrorMessage(E_PRIVILEGE_DENIED));

	bool isDataServiceAvailable = false;

	isDataServiceAvailable = __pNetworkStatusImpl->IsDataServiceAvailable();

	return isDataServiceAvailable;
}

}} // Tizen::Telephony
