//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_CallForwardEvent.cpp
 * @brief   This is the implementation file for the _CallForwardEvent Class.
 *
 * This header file contains implementation of the _CallForwardEvent Class.
 */

#include <FBaseRtIEventListener.h>
#include <FBaseColArrayList.h>
#include <FBaseSysLog.h>
#include <FTelITelephonyCallForwardListener.h>
#include "FTel_CallForwardEvent.h"
#include "FTel_CallForwardEventArg.h"


using namespace Tizen::Base::Collection;

namespace Tizen { namespace Telephony
{

////////////////////////////////////////////////////////////////////////////
_CallForwardEvent::_CallForwardEvent(void)
{
}

_CallForwardEvent::~_CallForwardEvent(void)
{
}

result
_CallForwardEvent::Construct(void)
{
    return _Event::Initialize();
}

////////////////////////////////////////////////////////////////////////////////
/// Operation : Protected

void
_CallForwardEvent::FireImpl(Tizen::Base::Runtime::IEventListener& listener, const Tizen::Base::Runtime::IEventArg& arg)
{
    const _CallForwardEventArg* pArg = dynamic_cast<const _CallForwardEventArg*>(&arg);
    SysTryReturnVoidResult(NID_TEL, pArg != null, E_INVALID_ARG, "[%s] Invalid argument used. The arg is a null pointer.", GetErrorMessage(E_INVALID_ARG));

    ITelephonyCallForwardListener* pCallForwardListner = dynamic_cast<ITelephonyCallForwardListener*>(&listener);
    SysTryReturnVoidResult(NID_TEL, pCallForwardListner != null, E_INVALID_ARG,
            "[%s] Invalid argument used. The result of a dynamic_cast operation is null for call forward listener", GetErrorMessage(E_INVALID_ARG));

    _CallForwardEventType eventType = pArg->GetEventType();

    switch(eventType)
    {
    case _CALL_FORWARD_EVENT_NUMBER_RECEIVED:
        pCallForwardListner->OnTelephonyCallForwardNumberReceived(pArg->GetPhoneNumber(), pArg->GetError());
        break;
    case _CALL_FORWARD_EVENT_RESPONSE_RECEIVED:
        pCallForwardListner->OnTelephonyCallForwardResponseReceived(pArg->GetPhoneNumber(), pArg->GetError());
        break;
    case _CALL_FORWARD_EVENT_STOPPED:
        pCallForwardListner->OnTelephonyCallForwardStopped(pArg->GetPhoneNumber(), pArg->GetError());
        break;
    default:
        break;
    }
}

} } // Tizen::Telephony
