//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_CallForwardEventArg.h
 * @brief       This is the header file for _CallForwardEventArg class.
 *
 * This header file contains the declarations of _CallForwardEventArg class.
 */


#ifndef _FTEL_INTERNAL_CALL_FORWARD_EVENT_ARG_H_
#define _FTEL_INTERNAL_CALL_FORWARD_EVENT_ARG_H_

// Includes
#include <FBaseObject.h>
#include <FBaseDataType.h>
#include <FBaseString.h>
#include <FBaseRtIEventArg.h>

namespace Tizen { namespace Base { namespace Collection
{
class IList;
}}}

namespace Tizen { namespace Telephony
{

enum _CallForwardEventType
{
    _CALL_FORWARD_EVENT_NONE,
    _CALL_FORWARD_EVENT_NUMBER_RECEIVED,
    _CALL_FORWARD_EVENT_RESPONSE_RECEIVED,
    _CALL_FORWARD_EVENT_STOPPED
};


/**
 * @class   _CallForwardEventArg
 * @brief   This class is used as an argument of methods of the ITelephonyCallForwardListener class.
 *
 * This class is used as an argument of ITelephonyCallForwardListenerListener methods.
 * When a CallManager event occurs, the _CallForwardingEvent object finds a ITelephonyCallForwardListenerListener object
 * which is registered for the CallManager object and calls an appropriate method of the listener.
 */

class _CallForwardEventArg
    : public Tizen::Base::Object
    , public Tizen::Base::Runtime::IEventArg
{
public:
    _CallForwardEventArg(void);

    _CallForwardEventArg(_CallForwardEventType eventType, Tizen::Base::String phoneNumber, result r);

    virtual ~_CallForwardEventArg(void);

    result GetError(void) const;

    _CallForwardEventType GetEventType(void) const;

    Tizen::Base::String GetPhoneNumber(void) const;

private:
    _CallForwardEventArg(const _CallForwardEventArg& rhs);
    _CallForwardEventArg& operator =(const _CallForwardEventArg& rhs);

private:
    result __error;
    _CallForwardEventType __eventType;
    Tizen::Base::String __phoneNumber;

}; // _CallForwardEventArg
} }

#endif // _FTEL_INTERNAL_CALL_FORWARD_EVENT_ARG_H_
