//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_CallInfoImpl.cpp
 * @brief       This is the implementation file for _CallInfoImpl class.
 */

#include <FBaseString.h>
#include <FTelTypes.h>
#include <FTelCallInfo.h>
#include "FTel_CallInfoImpl.h"

using namespace Tizen::Base;

namespace Tizen { namespace Telephony
{


_CallInfoImpl::_CallInfoImpl(void)
	: __callType(TYPE_UNDEFINED_CALL)
{
}

_CallInfoImpl::_CallInfoImpl(const _CallInfoImpl& callInfo)
	: __callType(callInfo.__callType)
	, __number(callInfo.__number)
{
}

_CallInfoImpl::_CallInfoImpl(CallType type, const String& number)
	: __callType(type)
	, __number(number)
{
}

_CallInfoImpl::~_CallInfoImpl(void)
{
}

_CallInfoImpl&
_CallInfoImpl::operator =(const _CallInfoImpl& rhs)
{
	if (this != &rhs)
	{
		__callType = rhs.__callType;
		__number = rhs.__number;
	}

	return *this;
}

CallType
_CallInfoImpl::GetCallType(void) const
{
	return __callType;
}

String
_CallInfoImpl::GetNumber(void) const
{
	return __number;
}

void
_CallInfoImpl::SetCallType(CallType callType)
{
	__callType = callType;
}

void
_CallInfoImpl::SetNumber(const String& number)
{
	__number = number;
}

bool
_CallInfoImpl::Equals(const Object& obj) const
{
	const _CallInfoImpl* pOther = dynamic_cast<const _CallInfoImpl*>(&obj);

	if (pOther == null
		||__callType != pOther->__callType
		||!__number.Equals(pOther->__number))
	{
		return false;
	}

	return true;
}

int
_CallInfoImpl::GetHashCode(void) const
{
	return __callType ^ __number.GetHashCode();
}

_CallInfoImpl*
_CallInfoImpl::GetInstance(CallInfo& callInfo)
{
	return callInfo.__pCallInfoImpl;
}

const _CallInfoImpl*
_CallInfoImpl::GetInstance(const CallInfo& callInfo)
{
	return callInfo.__pCallInfoImpl;
}

}} // Tizen::Telephony
