//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file    FTel_CallInfoImpl.h
 * @brief   This is the header file for the %_CallInfoImpl class.
 *
 * This header file contains the declarations of the %_CallInfoImpl class.
 */
#ifndef _FTEL_INTERNAL_CALL_INFO_IMPL_H_
#define _FTEL_INTERNAL_CALL_INFO_IMPL_H_


#include <FBaseObject.h>
#include <FBaseString.h>
#include <FTelTypes.h>


namespace Tizen { namespace Telephony
{
class CallInfo;

/**
 * @class _CallInfoImpl
 * @brief This class provides methods to obtain detailed information about a call.
 * @since 2.1
 *
 * The %_CallInfoImpl class provides methods to obtain detailed call information, such as the call type and number.
 */
class _CallInfoImpl
	: public Tizen::Base::Object
{
public:
	/**
     * This is the default constructor for this class.
     *
     *  @since 2.1
     */
	_CallInfoImpl(void);

	/**
     * This is the copy constructor for the %_CallInfoImpl class.
     *
     * @since 2.1
     *
     * @param[in] rhs The call information
     */
	_CallInfoImpl(const _CallInfoImpl& rhs);

	/**
     * Initializes this instance of %_CallInfoImpl with the specified call type and the phone number.
     *
     * @param[in] type   The call type
     * @param[in] number The phone number @n
     */
	_CallInfoImpl(CallType type, const Tizen::Base::String& number);

	/**
     * This is the destructor for this class.
     *
     * @since 2.1
     */
	virtual ~_CallInfoImpl(void);

	/**
     * @see CallInfo::GetCallType()
     */
	CallType GetCallType(void) const;

	/**
     * @see CallInfo::GetNumber()
     */
	Tizen::Base::String GetNumber(void) const;

	/**
     * Sets the call type.
     *
     * @param[in]   callType
     */
	void SetCallType(CallType callType);

	/**
     * Sets the phone number.
     *
     * @param[in]   number
     */
	void SetNumber(const Tizen::Base::String& number);

	/**
     * Checks whether the the specified instance of %_CallInfoImpl equals the current instance.
     *
     * @return   @c true if the specified instance equals the current instance, @n
     *           else @c false
     * @param[in]   obj An instance of %_CallInfoImpl
     * @remarks  The method returns @c false if the specified object is not %_CallInfoImpl.
     */
	virtual bool Equals(const Tizen::Base::Object& obj) const;

	/**
     * Gets the hash value of the current instance.
     *
     * @return   The hash value of the current instance
     */
	virtual int GetHashCode(void) const;

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return  The pointer to _CallInfoImpl
     * @param[in]   callInfo   An instance of CallInfo
     */
	static _CallInfoImpl* GetInstance(CallInfo& callInfo);

	/**
     * Gets the Impl instance.static int OnCallStatusChanged(const TelTapiEvent_t* pTapiEvent, void* pUserData);
     *
     *
     * @since 2.1
     * @return  The pointer to _CallInfoImpl
     * @param[in]   callInfo   An instance of CallInfo
     */
	static const _CallInfoImpl* GetInstance(const CallInfo& callInfo);

	/**
     * This is the assignment operator.
     *
     * @param[in] rhs An instance of %_CallInfoImpl
     */
	_CallInfoImpl& operator =(const _CallInfoImpl& rhs);

private:
	CallType __callType;
	Tizen::Base::String __number;

}; // _CallInfoImpl

}} // Tizen::Telephony
#endif // _FTEL_INTERNAL_CALL_INFO_IMPL_H_
