//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_CallManagerEvent.cpp
 * @brief   This is the implementation file for the _CallManagerEvent Class.
 *
 * This header file contains implementation of the _CallManagerEvent Class.
 */

#include <FBaseRtIEventListener.h>
#include <FBaseSysLog.h>
#include <FTelITelephonyCallEventListener.h>
#include "FTel_CallManagerEvent.h"
#include "FTel_CallManagerEventArg.h"


namespace Tizen { namespace Telephony
{

////////////////////////////////////////////////////////////////////////////
_CallManagerEvent::_CallManagerEvent(void)
{
}

_CallManagerEvent::~_CallManagerEvent(void)
{
}

result
_CallManagerEvent::Construct(void)
{
    return _Event::Initialize();
}

////////////////////////////////////////////////////////////////////////////////
/// Operation : Protected

void
_CallManagerEvent::FireImpl(Tizen::Base::Runtime::IEventListener& listener, const Tizen::Base::Runtime::IEventArg& arg)
{
    const _CallManagerEventArg* pArg = dynamic_cast<const _CallManagerEventArg*>(&arg);
    SysTryReturnVoidResult(NID_TEL, pArg != null, E_INVALID_ARG, "[%s] Invalid argument used. The arg is null pointer.", GetErrorMessage(E_INVALID_ARG));

    ITelephonyCallEventListener* pListener = dynamic_cast<ITelephonyCallEventListener*>(&listener);
    SysTryReturnVoidResult(NID_TEL, pListener != null, E_INVALID_ARG,
            "[%s] Invalied argument used. The result of dynamic_cast operation is null for telephony network event listener", GetErrorMessage(E_INVALID_ARG));

    pListener->OnTelephonyCallStatusChangedN(pArg->GetCallStatus(), pArg->GetCallInfoN());
}

} } // Tizen::Telephony
