//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_CallManagerEventArg.cpp
 * @brief       This is the implementation file for the %_EmailEventArg class.
 *
 * This file contains the implementation of the %_EmailEventArg class.
 */

#include <FBaseErrorDefine.h>
#include <FBaseSysLog.h>
#include <FTelTypes.h>
#include <FTelCallInfo.h>
#include "FTel_CallManagerEventArg.h"

namespace Tizen { namespace Telephony
{

_CallManagerEventArg::_CallManagerEventArg(void)
    : __callStatus(CALL_STATUS_UNDEFINED)
    , __pCallInfo(null)
{
}

_CallManagerEventArg::_CallManagerEventArg(CallStatus callStatus, CallInfo* pCallInfo)
    : __callStatus(callStatus)
    , __pCallInfo(pCallInfo)
{

}


CallStatus
_CallManagerEventArg::GetCallStatus(void) const
{
    return __callStatus;
}

CallInfo*
_CallManagerEventArg::GetCallInfoN(void) const
{
    CallInfo* pCallInfo = null;

    if (__pCallInfo != null)
    {
        pCallInfo = new (std::nothrow) CallInfo(*(__pCallInfo.get()));
        SysTryReturn(NID_TEL, pCallInfo != null, pCallInfo, E_OUT_OF_MEMORY, "[%s] Memory allocation failed.", GetErrorMessage(E_OUT_OF_MEMORY));
    }

    return pCallInfo;
}

} } // Tizen::Telephony
