//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_CallManagerEventArg.h
 * @brief       This is the header file for _CallManagerEventArg class.
 *
 * This header file contains the declarations of _CallManagerEventArg class.
 */


#ifndef _FTEL_INTERNAL_CALL_MANAGER_EVENT_ARG_H_
#define _FTEL_INTERNAL_CALL_MANAGER_EVENT_ARG_H_

// Includes
#include <unique_ptr.h>
#include <FBaseObject.h>
#include <FBaseDataType.h>
#include <FBaseRtIEventArg.h>
#include <FTelNetworkStatus.h>

namespace Tizen { namespace Telephony
{


/**
 * @class   _CallManagerEventArg
 * @brief   This class is used as an argument of methods of the ITelephonyCallEventListener class.
 *
 * This class is used as an argument of ITelephonyCallEventListener methods.
 * When a CallManager event occurs, the _CallManagerEvent object finds a ITelephonyCallEventListener object
 * which is registered for the CallManager object and calls an appropriate method of the listener.
 */

class _CallManagerEventArg
    : public Tizen::Base::Object
    , public Tizen::Base::Runtime::IEventArg
{
public:
    /**
    * This is the constructor.
    *
    */
    _CallManagerEventArg(void);

    /**
    * This constructor initializes the instance of this class with the specified values.
    *
    * @param[in]    callStatus An instance of %CallStatus
    * @param[in]    pCallInfo  A pointer to a CallInfo instance
    */
    _CallManagerEventArg(CallStatus callStatus, CallInfo* pCallInfo);

    /**
    * This is class destructor.
    */
    virtual ~_CallManagerEventArg(void){}

    /**
     * Gets the call status
     * @return  The instance of CallStatus
     */
    CallStatus GetCallStatus(void) const;

    /**
     * Gets the call information
     * @return  A pointer to a CallInfo instance
     */
    CallInfo* GetCallInfoN(void) const;


private:
    _CallManagerEventArg(const _CallManagerEventArg& rhs);
    _CallManagerEventArg& operator =(const _CallManagerEventArg& rhs);

private:
    CallStatus __callStatus;
    std::unique_ptr<CallInfo> __pCallInfo;

}; // _CallManagerEventArg
} }

#endif // _FTEL_INTERNAL_CALL_MANAGER_EVENT_ARG_H_
