//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_NetworkInfoImpl.cpp
 * @brief       This is the implementation file for _NetworkInfoImpl class.
 */

#include <telephony_network.h>
#include <FTelNetworkInfo.h>
#include <FBaseErrors.h>
#include <FBaseSysLog.h>
#include "FTel_NetworkInfoImpl.h"

using namespace Tizen::Base;

namespace Tizen { namespace Telephony
{


_NetworkInfoImpl::_NetworkInfoImpl(void)
	: __cellId(-1)
	, __lac(-1)
    , __mcc(-1)
    , __mnc(-1)
    , __networkType(_NETWORK_TYPE_UNDEFINED)
{
}

_NetworkInfoImpl::_NetworkInfoImpl(const _NetworkInfoImpl& value)
    : __cellId(value.__cellId)
    , __lac(value.__lac)
    , __mcc(value.__mcc)
    , __mnc(value.__mnc)
    , __plmn(value.__plmn)
    , __operatorName(value.__operatorName)
    , __networkType(value.__networkType)
{
}

_NetworkInfoImpl::~_NetworkInfoImpl(void)
{
}

int
_NetworkInfoImpl::GetCellId(void) const
{
    return __cellId;
}

int
_NetworkInfoImpl::GetLac(void) const
{
    return __lac;
}

int
_NetworkInfoImpl::GetMcc(void) const
{
    return __mcc;
}

int
_NetworkInfoImpl::GetMnc(void) const
{
    return __mnc;
}
String
_NetworkInfoImpl::GetPlmn(void) const
{
	return __plmn;
}

String
_NetworkInfoImpl::GetOperatorName(void) const
{
    return __operatorName;
}

_NetworkType
_NetworkInfoImpl::GetNetworkType(void) const
{
    return __networkType;
}

bool
_NetworkInfoImpl::Equals(const Object& obj) const
{
	const _NetworkInfoImpl* pOther = static_cast<const _NetworkInfoImpl*>(&obj);

    if (pOther == null
        || __cellId != pOther->__cellId
        || __lac != pOther->__lac
        || __mcc != pOther->__mcc
        || __mnc != pOther->__mnc
        || __plmn != pOther->__plmn
        || __operatorName != pOther->__operatorName
        || __networkType != pOther->__networkType)
    {
        return false;
    }

	return true;
}

int
_NetworkInfoImpl::GetHashCode(void) const
{
	static const int _PRIME_NUMBER = 31;
	int hashCode = 0;

    hashCode = _PRIME_NUMBER * __mcc;
    hashCode = (_PRIME_NUMBER * hashCode) ^ __mnc;
    hashCode = (_PRIME_NUMBER * hashCode) ^ __cellId;
    hashCode = (_PRIME_NUMBER * hashCode) ^ __lac;
    hashCode = (_PRIME_NUMBER * hashCode) ^ __plmn.GetHashCode();
    hashCode = (_PRIME_NUMBER * hashCode) ^ __operatorName.GetHashCode();
    hashCode = (_PRIME_NUMBER * hashCode) ^ __networkType;

	return hashCode;
}
int
_NetworkInfoImpl::GetRssi(void)
{
	static const int rssiArray[] = {10, 25, 45, 60, 75, 75, 90};
	network_info_rssi_e rssi;
	int err = NETWORK_INFO_ERROR_NONE;

	err = network_info_get_rssi(&rssi);
	SysLog(NID_TEL, "network_info_get_rssi() returned %d value and the rssi value is %d", err, rssi);
	SysTryReturn(NID_TEL, err == NETWORK_INFO_ERROR_NONE, 0, E_SYSTEM,
	        "[%s] A system error has occurred. Failed to get the received signal strength indication.", GetErrorMessage(E_SYSTEM));

	return rssiArray[rssi];
}

void
_NetworkInfoImpl::SetCellId(int cellId)
{
	__cellId = cellId;
}

void
_NetworkInfoImpl::SetLac(int lac)
{
	__lac = lac;
}

void
_NetworkInfoImpl::SetMcc(int mcc)
{
    __mcc = mcc;
}

void
_NetworkInfoImpl::SetMnc(int mnc)
{
    __mnc = mnc;
}

void
_NetworkInfoImpl::SetPlmn(const String& plmn)
{
    __plmn = plmn;
}

void
_NetworkInfoImpl::SetOperatorName(const String& operatorName)
{
    __operatorName = operatorName;
}

void
_NetworkInfoImpl::SetNetworkType(_NetworkType networkType)
{
    __networkType = networkType;
}


_NetworkInfoImpl&
_NetworkInfoImpl::operator=(const _NetworkInfoImpl& rhs)
{
    if (this != &rhs)
    {
        __cellId = rhs.__cellId;
        __lac = rhs.__lac;
        __mcc = rhs.__mcc;
        __mnc = rhs.__mnc;
        __plmn = rhs.__plmn;
        __operatorName = rhs.__operatorName;
        __networkType = rhs.__networkType;

    }
    return *this;
}

_NetworkInfoImpl*
_NetworkInfoImpl::GetInstance(NetworkInfo& networkInfo)
{
	return networkInfo.__pNetworkInfoImpl;
}

const _NetworkInfoImpl*
_NetworkInfoImpl::GetInstance(const NetworkInfo& networkInfo)
{
	return networkInfo.__pNetworkInfoImpl;
}

}} // Tizen::Telephony
