//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_NetworkManagerEvent.cpp
 * @brief   This is the implementation file for the _NetworkManagerEvent Class.
 *
 * This header file contains implementation of the _NetworkManagerEvent Class.
 */

#include <FBaseRtIEventListener.h>
#include <FBaseSysLog.h>
#include <FTelITelephonyNetworkEventListener.h>
#include "FTel_NetworkManagerEvent.h"
#include "FTel_NetworkManagerEventArg.h"


namespace Tizen { namespace Telephony
{

////////////////////////////////////////////////////////////////////////////
_NetworkManagerEvent::_NetworkManagerEvent(void)
{
}

_NetworkManagerEvent::~_NetworkManagerEvent(void)
{
}

result
_NetworkManagerEvent::Construct(void)
{
    return _Event::Initialize();
}

////////////////////////////////////////////////////////////////////////////////
/// Operation : Protected

void
_NetworkManagerEvent::FireImpl(Tizen::Base::Runtime::IEventListener& listener, const Tizen::Base::Runtime::IEventArg& arg)
{
    const _NetworkManagerEventArg* pArg = dynamic_cast<const _NetworkManagerEventArg*>(&arg);
    SysTryReturnVoidResult(NID_TEL, pArg != null, E_INVALID_ARG, "[%s] Invalid argument used. The arg is a null pointer.", GetErrorMessage(E_INVALID_ARG));

    ITelephonyNetworkEventListener* pListener = dynamic_cast<ITelephonyNetworkEventListener*>(&listener);
    SysTryReturnVoidResult(NID_TEL, pListener != null, E_INVALID_ARG,
            "[%s] Invalid argument used. The result of a dynamic_cast operation is null for telephony network event listener", GetErrorMessage(E_INVALID_ARG));

    pListener->OnTelephonyNetworkStatusChanged(pArg->GetNetworkStatus());
}

} } // Tizen::Telephony
