//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_NetworkManagerEventArg.h
 * @brief       This is the header file for _NetworkManagerEventArg class.
 *
 * This header file contains the declarations of _NetworkManagerEventArg class.
 */


#ifndef _FTEL_INTERNAL_NETWORK_MANAGER_EVENT_ARG_H_
#define _FTEL_INTERNAL_NETWORK_MANAGER_EVENT_ARG_H_

// Includes
#include <FBaseObject.h>
#include <FBaseDataType.h>
#include <FBaseRtIEventArg.h>
#include <FTelNetworkStatus.h>

namespace Tizen { namespace Telephony
{


/**
 * @class   _NetworkManagerEventArg
 * @brief   This class is used as an argument of methods of the ITelephonyNetworkEventListener class.
 *
 * This class is used as an argument of ITelephonyNetworkEventListener methods.
 * When a NetworkManager event occurs, the _NetworkManagerEvent object finds a ITelephonyNetworkEventListener object
 * which is registered for the NetworkManager object and calls an appropriate method of the listener.
 */

class _NetworkManagerEventArg
    : public Tizen::Base::Object
    , public Tizen::Base::Runtime::IEventArg
{
public:
    /**
    * This is the constructor.
    *
    */
    _NetworkManagerEventArg(void);

    /**
    * This constructor initializes the instance of this class with the specified values.
    *
    * @param[in]    networkstatus An instance of %NetworkStatus
    */
    _NetworkManagerEventArg(const NetworkStatus& networkstatus);

    /**
    * This is class destructor.
    */
    virtual ~_NetworkManagerEventArg(void) {};


    /**
     * Gets the network status
     * @return  The instance of NetworkStatus
     */
    const NetworkStatus& GetNetworkStatus(void) const;

    /**
     * Gets the error code.
     * @return  Error code of this argument.
     */
    result GetError(void) const;

private:
    _NetworkManagerEventArg(const _NetworkManagerEventArg& rhs);
    _NetworkManagerEventArg& operator =(const _NetworkManagerEventArg& rhs);

private:
    NetworkStatus __networkStatus;
    result __error;
}; // _NetworkManagerEventArg
} }

#endif // _FTEL_INTERNAL_NETWORK_MANAGER_EVENT_ARG_H_
