//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_NetworkSettingEvent.h
 * @brief   This is the header file for the _NetworkSettingEvent class.
 *
 * This header file contains declarations of the _NetworkSettingEvent class.
 */

#ifndef _FTEL_INTERNAL_NETWORK_SETTING_EVENT_H_
#define _FTEL_INTERNAL_NETWORK_SETTING_EVENT_H_

// Includes
#include <FBaseResult.h>
#include <FBaseRt_Event.h>

namespace Tizen { namespace Base { namespace Runtime
{
class IEventListener;
class IEventArg;
}}}

namespace Tizen { namespace Telephony
{

/**
 * @class   _NetworkSettingEvent
 * @brief   This class handles NetworkManager events related to network setting.
 *
 * When a NetworkManager event related to network setting occurs, the _NetworkSettingEvent object finds a ITelephonyNetworkSettingListener object
 * which is registered for the Device object and calls an appropriate method of the listener.
 */

class _NetworkSettingEvent
    : public Tizen::Base::Runtime::_Event
{
public:
    /**
     * This is the default constructor for this class.
     */
    _NetworkSettingEvent();

    /**
     * This is the class destructor.
     */
    virtual ~_NetworkSettingEvent(void);


    /**
     * Initializes a new instance of the  class
     *
     */
    result Construct(void);

protected:
    /**
     * Checks the arg and finds out the type of event. After that this method calls appropriate pListener's method.
     *
     * @return      A result code.
     * @param[in]   listener        It is a event listener related to network setting event.
     * @param[in]   arg             It is an argument-like instance of NetworkManager event retransmitted to the listener's method as an argument.
     * @exception   E_SUCCESS       The method is successful.
     * @exception   E_INVALID_ARG   The argument passed to a method contains an invalid value.@n
     */
    void FireImpl(Tizen::Base::Runtime::IEventListener& listener, const Tizen::Base::Runtime::IEventArg& arg);


private:
    _NetworkSettingEvent(const _NetworkSettingEvent& rhs);
    _NetworkSettingEvent& operator =(const _NetworkSettingEvent& rhs);

}; // _NetworkSettingEvent

}} // Tizen::Telephony
#endif // _FTEL_INTERNAL_NETWORK_SETTING_EVENT_H_
