//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_NetworkSettingEventArg.cpp
 * @brief       This is the implementation file for the %_NetworkSettingEventArg class.
 *
 * This file contains the implementation of the %_NetworkSettingEventArg class.
 */

#include <FBaseErrorDefine.h>
#include <FBaseColArrayList.h>
#include "FTel_NetworkSettingEventArg.h"

namespace Tizen { namespace Telephony
{

_NetworkSettingEventArg::_NetworkSettingEventArg(void)
    : __error(E_SUCCESS)
    , __eventType(_NETWORK_EVENT_NONE)
    , __isManual(false)
    , __pNetworkInfoList(null)
{
}

_NetworkSettingEventArg::_NetworkSettingEventArg(_NetworkSettingEventType networkType, bool isManual, result r)
    : __error(r)
    , __eventType(networkType)
    , __isManual(isManual)
    , __pNetworkInfoList(null)
{

}

_NetworkSettingEventArg::_NetworkSettingEventArg(_NetworkSettingEventType networkType, result r)
    : __error(r)
    , __eventType(networkType)
    , __isManual(false)
    , __pNetworkInfoList(null)
{

}

_NetworkSettingEventArg::_NetworkSettingEventArg(_NetworkSettingEventType networkType, Tizen::Base::Collection::IList* pNetworkInfoList, result r)
    : __error(r)
    , __eventType(networkType)
    , __isManual(false)
    , __pNetworkInfoList(pNetworkInfoList)
{

}


_NetworkSettingEventArg::~_NetworkSettingEventArg(void)
{
    if (__pNetworkInfoList != null)
    {
        __pNetworkInfoList->RemoveAll(true);
        delete __pNetworkInfoList;
    }
}


result
_NetworkSettingEventArg::GetError(void) const
{
    return __error;
}

_NetworkSettingEventType
_NetworkSettingEventArg::GetEventType(void) const
{
    return __eventType;
}

bool
_NetworkSettingEventArg::GetIsManual(void) const
{
    return __isManual;
}

Tizen::Base::Collection::IList*
_NetworkSettingEventArg::GetNetworkInfoList(void) const
{
    return __pNetworkInfoList;
}


} } // Tizen::Telephony
