//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_NetworkSettingEventArg.h
 * @brief       This is the header file for _NetworkSettingEventArg class.
 *
 * This header file contains the declarations of _NetworkSettingEventArg class.
 */


#ifndef _FTEL_INTERNAL_NETWORK_SETTING_EVENT_ARG_H_
#define _FTEL_INTERNAL_NETWORK_SETTING_EVENT_ARG_H_

// Includes
#include <FBaseObject.h>
#include <FBaseDataType.h>
#include <FBaseRtIEventArg.h>

namespace Tizen { namespace Base { namespace Collection
{
class IList;
}}}

namespace Tizen { namespace Telephony
{

enum _NetworkSettingEventType
{
    _NETWORK_EVENT_NONE,
    _NETWORK_EVENT_GET_SELECTION_MODE,
    _NETWORK_EVENT_SELECT_NETWORK,
    _NETWORK_EVENT_SEARCH_COMPLETED
};


/**
 * @class   _NetworkSettingEventArg
 * @brief   This class is used as an argument of methods of the ITelephonyNetworkSettingListener class.
 *
 * This class is used as an argument of ITelephonyNetworkSettingListener methods.
 * When a NetworkManager event occurs, the _NetworkSettingEvent object finds a ITelephonyNetworkSettingListener object
 * which is registered for the NetworkManager object and calls an appropriate method of the listener.
 */

class _NetworkSettingEventArg
    : public Tizen::Base::Object
    , public Tizen::Base::Runtime::IEventArg
{
public:
    _NetworkSettingEventArg(void);

    _NetworkSettingEventArg(_NetworkSettingEventType networkType, bool isManual, result r);

    _NetworkSettingEventArg(_NetworkSettingEventType networkType, result r);

    _NetworkSettingEventArg(_NetworkSettingEventType networkType, Tizen::Base::Collection::IList* pNetworkInfoList, result r);

    virtual ~_NetworkSettingEventArg(void);

    /**
     * @brief   Gets the error code.
     * @return  Error code of this argument.
     */
    result GetError(void) const;

    _NetworkSettingEventType GetEventType(void) const;

    bool GetIsManual(void) const;

    /**
     * @brief       Gets the list of NetworkInfo.
     * @return      Pointer to the ArrayList object which contains information of NetoworkInfo.
     */
    Tizen::Base::Collection::IList* GetNetworkInfoList(void) const;

private:
    _NetworkSettingEventArg(const _NetworkSettingEventArg& rhs);
    _NetworkSettingEventArg& operator =(const _NetworkSettingEventArg& rhs);

private:
    result __error;
    _NetworkSettingEventType __eventType;
    bool __isManual;
    Tizen::Base::Collection::IList* __pNetworkInfoList;

}; // _NetworkSettingEventArg
} }

#endif // _FTEL_INTERNAL_NETWORK_MANAGER_EVENT_ARG_H_
