//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_NetworkStatusImpl.cpp
 * @brief       This is the implementation file for _NetworkStatusImpl class.
 */

#include <FTelNetworkStatus.h>
#include "FTel_NetworkStatusImpl.h"

namespace Tizen { namespace Telephony
{


_NetworkStatusImpl::_NetworkStatusImpl(void)
	: __isRoaming(false)
	, __isCallServiceAvailable(false)
	, __isDataServiceAvailable(false)
{
}

_NetworkStatusImpl::~_NetworkStatusImpl(void)
{
}

_NetworkStatusImpl::_NetworkStatusImpl(const _NetworkStatusImpl& rhs)
    : __isRoaming(rhs.__isRoaming)
    , __isCallServiceAvailable(rhs.__isCallServiceAvailable)
    , __isDataServiceAvailable(rhs.__isDataServiceAvailable)
{

}

bool
_NetworkStatusImpl::IsRoaming(void) const
{
	return __isRoaming;
}

bool
_NetworkStatusImpl::IsCallServiceAvailable(void) const
{
	return __isCallServiceAvailable;
}

bool
_NetworkStatusImpl::IsDataServiceAvailable(void) const
{
	return __isDataServiceAvailable;
}

void
_NetworkStatusImpl::SetIsRoaming(bool isRoaming)
{
	__isRoaming = isRoaming;
}

void
_NetworkStatusImpl::SetIsCallServiceAvailable(bool isCallServiceAvailable)
{
	__isCallServiceAvailable = isCallServiceAvailable;
}

void
_NetworkStatusImpl::SetIsDataServiceAvailable(bool isDataServiceAvailable)
{
	__isDataServiceAvailable = isDataServiceAvailable;
}

_NetworkStatusImpl*
_NetworkStatusImpl::GetInstance(NetworkStatus& networkStatus)
{
	return networkStatus.__pNetworkStatusImpl;
}

const _NetworkStatusImpl*
_NetworkStatusImpl::GetInstance(const NetworkStatus& networkStatus)
{
	return networkStatus.__pNetworkStatusImpl;
}

_NetworkStatusImpl&
_NetworkStatusImpl::operator =(const _NetworkStatusImpl& rhs)
{

    if (this != &rhs)
    {
        __isRoaming = rhs.__isRoaming;
        __isCallServiceAvailable = rhs.__isCallServiceAvailable;
        __isDataServiceAvailable = rhs.__isDataServiceAvailable;
    }

   return *this;

}

}} // Tizen::Telephony
