//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file	FTel_NetworkStatusImpl.h
 * @brief	This is the header file for the _NetworkStatusImpl class.
 *
 * This header file contains the declarations of the _NetworkStatusImpl class.
 */
#ifndef _FTEL_INTERNAL_NETWORK_STATUS_IMPL_H_
#define _FTEL_INTERNAL_NETWORK_STATUS_IMPL_H_


#include <FBaseObject.h>


namespace Tizen { namespace Telephony
{
class NetworkStatus;

class _NetworkStatusImpl
	: public Tizen::Base::Object
{
public:
	/**
     * This is the default constructor for this class.
     *
     * @since	1.0
     */
	_NetworkStatusImpl(void);

	/**
     * This is the destructor for this class.
     *
     * @since	1.0
     */
	virtual ~_NetworkStatusImpl(void);

    /**
     * This is the copy constructor for this class.
     *
     * @param[in]   rhs An instance of %_NetworkStatusImpl
     */
    _NetworkStatusImpl(const _NetworkStatusImpl& rhs);

    /**
     * @see NetworkStatus::IsRoaming()
     */
	bool IsRoaming(void) const;

	/**
     * @see NetworkStatus::IsCallServiceAvailable()
     */
	bool IsCallServiceAvailable(void) const;

	/**
     * @see NetworkStatus::IsDataServiceAvailable()
     */
	bool IsDataServiceAvailable(void) const;

	/**
     * Sets the current state of roaming.
     *
     * @param[in]   isRoaming   The current state of roaming
     */
	void SetIsRoaming(bool isRoaming);

	/**
     * Sets the current state whether call service is available.
     *
     * @param[in]   isCallServiceAvailable   The current state whether call service is available
     */
	void SetIsCallServiceAvailable(bool isCallServiceAvailable);

	/**
     * Sets the current state whether date service is available.
     *
     * @param[in]   isDataServiceAvailable   The current state whether date service is available
     */
	void SetIsDataServiceAvailable(bool isDataServiceAvailable);

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return The pointer to _NetworkStatusImpl
     * @param[in] networkStatus   An instance of NetworkStatus
     */
	static _NetworkStatusImpl* GetInstance(NetworkStatus& networkStatus);

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return The pointer to _NetworkStatusImpl
     * @param[in] networkStatus   An instance of NetworkStatus
     */
	static const _NetworkStatusImpl* GetInstance(const NetworkStatus& networkStatus);


	/**
     * This is the assignment operator for this class. Do @b not use directly.
     *
     * @param[in]	rhs	An instance of %_NetworkStatusImpl
     */
	_NetworkStatusImpl& operator =(const _NetworkStatusImpl& rhs);

private:
	bool __isRoaming;
	bool __isCallServiceAvailable;
	bool __isDataServiceAvailable;

}; // _NetworkStatusImpl

}} // Tizen::Telephony
#endif // _FTEL_INTERNAL_NETWORK_STATUS_IMPL_H_
