//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_SimEvent.cpp
 * @brief   This is the implementation file for the _SimEvent Class.
 *
 * This header file contains implementation of the _SimEvent Class.
 */

#include <FBaseRtIEventListener.h>
#include <FBaseSysLog.h>
#include <FTelITelephonySimEventListener.h>
#include "FTel_SimEvent.h"
#include "FTel_SimEventArg.h"


using namespace Tizen::Base::Runtime;

namespace Tizen { namespace Telephony
{

_SimEvent::_SimEvent(void)
{
}

_SimEvent::~_SimEvent(void)
{
}

result
_SimEvent::Construct(void)
{
    return _Event::Initialize();
}

void
_SimEvent::FireImpl(IEventListener& listener, const IEventArg& arg)
{
	const _SimEventArg* pArg = dynamic_cast<const _SimEventArg*>(&arg);
	SysTryReturnVoidResult(NID_TEL, pArg != null, E_INVALID_ARG,
			"[%s] Invalid argument used. The arg is a null pointer.", GetErrorMessage(E_INVALID_ARG));

	ITelephonySimEventListener* pSimEventListener = dynamic_cast<ITelephonySimEventListener*>(&listener);
	SysTryReturnVoidResult(NID_TEL, pSimEventListener != null, E_INVALID_ARG,
			"[%s] Invalid argument used. The result of a dynamic_cast operation is null for SIM manager listener", GetErrorMessage(E_INVALID_ARG));

	_SimEventType eventType = pArg->GetEventType();

	switch(eventType)
	{
	case _SIM_EVENT_SIM_STATE_CHANGED:
		SysLog(NID_TEL, "Calling OnTelephonySimStateChanged().");
		pSimEventListener->OnTelephonySimStateChanged(pArg->GetSimState());
		SysLog(NID_TEL, "Called OnTelephonySimStateChanged().");
		break;
	default:
		break;
	}
}

} } // Tizen::Telephony
