//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_SimEventArg.h
 * @brief       This is the header file for _SimEventArg class.
 *
 * This header file contains the declarations of _SimEventArg class.
 */


#ifndef _FTEL_INTERNAL_SIM_EVENT_ARG_H_
#define _FTEL_INTERNAL_SIM_EVENT_ARG_H_

#include <FBaseObject.h>
#include <FBaseDataType.h>
#include <FBaseRtIEventArg.h>
#include <FTelTypes.h>

namespace Tizen { namespace Telephony
{

enum _SimEventType
{
	_SIM_EVENT_NONE,
	_SIM_EVENT_SIM_STATE_CHANGED
};


/**
 * @class   _SimEventArg
 * @brief   This class is used as an argument of methods of the ITelephonySimEventListener class.
 *
 * This class is used as an argument of ITelephonyNetworkEventListener methods.
 * When a SimManager event occurs, the _SimEvent object finds a ITelephonySimEventListener object
 * which is registered for the SimManager object and calls an appropriate method of the listener.
 */

class _SimEventArg
    : public Tizen::Base::Object
    , public Tizen::Base::Runtime::IEventArg
{
public:
    _SimEventArg(void);

    _SimEventArg(_SimEventType type, SimState state);

    virtual ~_SimEventArg(void) {};

    _SimEventType GetEventType(void) const;

    SimState GetSimState(void) const;

private:
    _SimEventArg(const _SimEventArg& rhs);
    _SimEventArg& operator =(const _SimEventArg& rhs);

private:
    _SimEventType __eventType;
    SimState __simState;

}; // _SimEventArg

} } // Tizen::Telephony

#endif // _FTEL_INTERNAL_SIM_EVENT_ARG_H_
