//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file	FTel_SimInfoImpl.h
 * @brief	This is the header file for the %_SimInfoImpl class.
 *
 * This header file contains the declarations of the %_SimInfoImpl class.
 */
#ifndef _FTEL_INTERNAL_SIM_INFO_IMPL_H_
#define _FTEL_INTERNAL_SIM_INFO_IMPL_H_

#include <ITapiSim.h>
#include <FBaseObject.h>


namespace Tizen { namespace Base
{
class String;
} } // Tizen::Base

namespace Tizen { namespace Telephony
{
class SimInfo;
class _TelephonyIpcProxy;

class _SimInfoImpl
	: public Tizen::Base::Object
{
public:
	/**
     * This is the default constructor for this class.
     *
     * @since 2.1
     */
	_SimInfoImpl(void);

	/**
	 * This is the copy constructor for the %_SimInfoImpl class.
	 *
	 * @since 2.1
	 * @param[in]	rhs		An instance of the %_SimInfoImpl class
	 */
	_SimInfoImpl(const _SimInfoImpl& rhs);

	/**
     * This is the destructor for this class.
     *
     * @since 2.1
     */
	virtual ~_SimInfoImpl(void);

	/**
     * @see SimInfo::Construct()
     */
	result Construct(void);

	/**
     * @see SimInfo::GetMnc()
     */
	int GetMnc(void) const;

	/**
     * @see SimInfo::GetMcc()
     */
	int GetMcc(void) const;

	/**
     * @see SimInfo::GetSpn()
     */
	Tizen::Base::String GetSpn(void) const;

	/**
     * @see SimInfo::GetIccId()
     */
	Tizen::Base::String GetIccId(void) const;

	/**
     * @see SimInfo::GetOperatorName()
     */
	Tizen::Base::String GetOperatorName(void) const;

	/**
     * @see SimInfo::GetPhoneNumber()
     */
	Tizen::Base::String GetPhoneNumber(void) const;

	/**
     * @see SimInfo::GetImsi()
     */
	Tizen::Base::String GetImsi(void) const;

	/**
	 * @see SimInfo::GetSimType()
	 */
	SimType GetSimType(void) const;

	/**
	 * @see	SimInfo::IsAvailable()
	 */
	bool IsAvailable(void) const;

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return The pointer to _SimInfoImpl
     * @param[in] simInfo    An instance of SimInfo
     */
	static _SimInfoImpl* GetInstance(SimInfo& simInfo);

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return The pointer to _SimInfoImpl
     * @param[in] simInfo    An instance of SimInfo
     */
	static const _SimInfoImpl* GetInstance(const SimInfo& simInfo);

	/**
     * This is the assignment operator for this class. Do @b not use directly.
     *
     * @param[in]   rhs An instance of %_SimInfoImpl
     */
	_SimInfoImpl& operator =(const _SimInfoImpl& rhs);

	/**
	 * @see		SimInfo::Equals()
	 */
	virtual bool Equals(const Tizen::Base::Object& rhs) const;

	/**
	 * @see		SimInfo::GetHashCode()1
	 */
	virtual int GetHashCode(void) const;

private:
	bool __isAvailable;

	friend class _SimStateManagerImpl;

}; // _SimInfoImpl

}} // Tizen::Telephony
#endif // _FTEL_INTERNAL_SIM_INFO_IMPL_H_
