//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_SimManagerEvent.cpp
 * @brief   This is the implementation file for the _SimManagerEvent Class.
 *
 * This header file contains implementation of the _SimManagerEvent Class.
 */

#include <unique_ptr.h>
#include <FBaseRtIEventListener.h>
#include <FBaseColArrayList.h>
#include <FBaseSysLog.h>
#include <FBaseColAllElementsDeleter.h>

#include <FTelISimStateManagerGetPinLockSettingResultListener.h>
#include "FTel_SimManagerEvent.h"
#include "FTel_SimManagerEventArg.h"

using namespace std;
using namespace Tizen::Base::Collection;
using namespace Tizen::Base::Runtime;

namespace Tizen { namespace Telephony
{

_SimManagerEvent::_SimManagerEvent(void)
{
}

_SimManagerEvent::~_SimManagerEvent(void)
{
}

result
_SimManagerEvent::Construct(void)
{
    return _Event::Initialize();
}


void
_SimManagerEvent::FireImpl(IEventListener& listener, const IEventArg& arg)
{
	const _SimManagerEventArg* pArg = dynamic_cast<const _SimManagerEventArg*>(&arg);
	SysTryReturnVoidResult(NID_TEL, pArg != null, E_INVALID_ARG,
			"[%s] Invalid argument used. The arg is a null pointer.", GetErrorMessage(E_INVALID_ARG));

	ISimStateManagerGetPinLockSettingResultListener* pSimStateManagerGetPinLockSettingResultListener = dynamic_cast<ISimStateManagerGetPinLockSettingResultListener*>(&listener);
	SysTryReturnVoidResult(NID_TEL, pSimStateManagerGetPinLockSettingResultListener != null, E_INVALID_ARG,
			"[%s] Invalid argument used. The result of a dynamic_cast operation is null for SIM manager listener", GetErrorMessage(E_INVALID_ARG));

	_SimManagerEventType eventType = pArg->GetEventType();

	switch(eventType)
	{
	case _SIM_MANAGER_EVENT_PIN_LOCK_SETTING_RESULT_RECEIVED:
		SysLog(NID_TEL, "Calling OnSimStateManagerGetPinLockSettingResultReceived().");
		pSimStateManagerGetPinLockSettingResultListener->OnSimStateManagerGetPinLockSettingResultReceived(pArg->IsPinLockEnabled(), pArg->GetResult());
		SysLog(NID_TEL, "Called OnSimStateManagerGetPinLockSettingResultReceived().");
		break;
	default:
		break;
	}
}

} } // Tizen::Telephony
