//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_SimManagerEventArg.cpp
 * @brief       This is the implementation file for the %_SimManagerEventArg class.
 *
 * This file contains the implementation of the %_SimManagerEventArg class.
 */

#include <FBaseErrorDefine.h>
#include <FBaseColArrayList.h>
#include "FTel_SimManagerEventArg.h"

namespace Tizen { namespace Telephony
{

_SimManagerEventArg::_SimManagerEventArg(void)
	: __eventType(_SIM_MANAGER_EVENT_NONE)
	, __isPinLockEnabled(false)
	, __result(E_SUCCESS)
{
}

_SimManagerEventArg::_SimManagerEventArg(_SimManagerEventType type, bool isEnabled, result r)
	: __eventType(type)
	, __isPinLockEnabled(isEnabled)
	, __result(r)
{
}

_SimManagerEventType
_SimManagerEventArg::GetEventType(void) const
{
	return __eventType;
}

result
_SimManagerEventArg::GetResult(void) const
{
	return __result;
}

bool
_SimManagerEventArg::IsPinLockEnabled(void) const
{
	return __isPinLockEnabled;
}

} } // Tizen::Telephony
