//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file        FTel_SimManagerEventArg.h
 * @brief       This is the header file for _SimManagerEventArg class.
 *
 * This header file contains the declarations of _SimManagerEventArg class.
 */


#ifndef _FTEL_INTERNAL_SIM_MANAGER_EVENT_ARG_H_
#define _FTEL_INTERNAL_SIM_MANAGER_EVENT_ARG_H_

#include <FBaseObject.h>
#include <FBaseDataType.h>
#include <FBaseRtIEventArg.h>
#include <FTelTypes.h>


namespace Tizen { namespace Telephony
{

enum _SimManagerEventType
{
	_SIM_MANAGER_EVENT_NONE,
	_SIM_MANAGER_EVENT_PIN_LOCK_SETTING_RESULT_RECEIVED
};


/**
 * @class   _SimManagerEventArg
 * @brief   This class is used as an argument of methods of the ISimStateManagerGetPinLockSettingResultListener class.
 *
 * This class is used as an argument of ISimStateManagerGetPinLockSettingResultListener methods.
 * When a SimStateManager event occurs, the _SimStateManagerEvent object finds a ISimStateManagerGetPinLockSettingResultListener object
 * which is registered for the Device object and calls an appropriate method of the listener.
 */

class _SimManagerEventArg
    : public Tizen::Base::Object
    , public Tizen::Base::Runtime::IEventArg
{
public:
    _SimManagerEventArg(void);
    _SimManagerEventArg(_SimManagerEventType type, bool isEnabled, result r);
    virtual ~_SimManagerEventArg(void) {};

    _SimManagerEventType GetEventType(void) const;
    result GetResult(void) const;
	bool IsPinLockEnabled(void) const;

private:
    _SimManagerEventArg(const _SimManagerEventArg& rhs);
    _SimManagerEventArg& operator =(const _SimManagerEventArg& rhs);

private:
    _SimManagerEventType __eventType;
    bool __isPinLockEnabled;
    result __result;

}; // _SimManagerEventArg

} }

#endif // _FTEL_INTERNAL_SIM_MANAGER_EVENT_ARG_H_
