//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file	FTel_SimStateManagerImpl.h
 * @brief	This is the header file for the %_SimStateManagerImpl class.
 *
 * This header file contains the declarations of the %_SimStateManagerImpl class.
 */

#ifndef _FTEL_INTERNAL_SIM_STATE_MANAGER_IMPL_H_
#define _FTEL_INTERNAL_SIM_STATE_MANAGER_IMPL_H_


#include <unique_ptr.h>
#include <net_connection.h>
#include <tapi_type.h>

#include <FBaseObject.h>
#include <FTelSimInfo.h>
#include <FTelSimStateManager.h>
#include <FTelTypes.h>


namespace Tizen { namespace Base
{
class String;
} } // Tizen::Base

namespace Tizen { namespace Telephony
{
class SimStateManager;
class _SimEvent;
class _SimManagerEvent;
class ITelephonySimEventListener;
class ISimStateManagerGetPinLockSettingResultListener;
//class _TelephonyIpcProxy;


class _SimStateManagerImpl
	: public Tizen::Base::Object
{
public:
	/**
	 * This is the default constructor for this class.
	 *
	 * @since	2.1
	 */
	_SimStateManagerImpl(void);

	/**
     * This is the destructor for this class.
     *
     * @since	2.1
     */
	virtual ~_SimStateManagerImpl(void);

	/**
     * @see	SimStateManager::Construct()
     */
	result Construct(void);

	/**
	 * @see	SimStateManager::SetSimEventListener()
	 */
	result SetSimEventListener(ITelephonySimEventListener *pListener);

	result SetSimStateManagerGetPinLockSettingResultListener(ISimStateManagerGetPinLockSettingResultListener *pListener);

	/**
	 * @see	SimStateManager::GetSimInfo()
	 */
	result GetSimInfo(SimInfo& simInfo) const;

	/**
	 * @see	SimStateManager::GetSimState()
	 */
	SimState GetSimState(void) const;

	/**
	 * @see	SimStateManager::GetPinLockSetting()
	 */
	result GetPinLockSetting(ISimStateManagerGetPinLockSettingResultListener* pListener);

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return The pointer to _SimStateManagerImpl
     * @param[in] simStateManager    An instance of SimStateManager
     */
	static _SimStateManagerImpl* GetInstance(SimStateManager& simStateManager);

	/**
     * Gets the Impl instance.
     *
     * @since 2.1
     * @return The pointer to _SimStateManagerImpl
     * @param[in] simStateManager    An instance of SimStateManager
     */
	static const _SimStateManagerImpl* GetInstance(const SimStateManager& simStateManager);

	static void OnSimStateChangedCallback(TapiHandle* pHandle, const char* pNotiId, void* pData, void* pUserData);
	static void OnGetPinLockSettingCallback(TapiHandle* pHandle, int ret, void* pData, void* pUserData);

private:
	//
    // The implementation of this copy constructor is intentionally blank and declared as private to prohibit copying of objects.
	//
	// @param[in]   rhs   An instance of %_SimStateManagerImpl
	//
	_SimStateManagerImpl(const _SimStateManagerImpl& rhs);

	//
	// The implementation of this copy assignment operator is intentionally blank and declared as private to prohibit copying of objects.
	//
	// @param[in]   rhs An instance of %_SimStateManagerImpl
	//
	_SimStateManagerImpl& operator =(const _SimStateManagerImpl& rhs);

private:
	TapiHandle* __pHandle;
	SimState __simState;
	bool __isInProgress;

	std::unique_ptr<_SimEvent> __pSimEvent;
	std::unique_ptr<_SimManagerEvent> __pSimManagerEvent;

	ITelephonySimEventListener* __pSimEventListener;
    ISimStateManagerGetPinLockSettingResultListener* __pSimStateManagerGetPinLockSettingResultListener;

}; // _SimStateManagerImpl

}} // Tizen::Telephony

#endif // _FTEL_INTERNAL_SIM_STATE_MANAGER_IMPL_H_
