//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file	FTel_TelephonyIpcProxy.h
 * @brief	This is the header file for the %_TelephonyIpcProxy class.
 *
 * This header file contains the declarations of the %_TelephonyIpcProxy class.
 */

#ifndef _FNET_WIFI_INTERNAL_TELEPHONY_IPC_PROXY_H_
#define _FNET_WIFI_INTERNAL_TELEPHONY_IPC_PROXY_H_

#include <tapi_type.h>
#include <FBaseObject.h>
#include <FIo_IpcCommonDataTypes.h>
#include <FIo_IIpcClientEventListener.h>

namespace Tizen { namespace Base {
class String;
} }

namespace Tizen { namespace Io {
class _IpcClient;
} }

namespace Tizen { namespace Telephony
{

class _NetworkManagerImpl;
class _CallManagerImpl;

/**
 * @class   _TelephonyIpcProxy
 * @brief   This class represents an IPC proxy for %Telephony service.
 *
 * This class represents an IPC proxy for %Telephony service to communicate with OSP Connectivity daemon.
 */
class _TelephonyIpcProxy
	: public Tizen::Base::Object
	, public Tizen::Io::_IIpcClientEventListener
{
public:

    // from _IIpcClientEventListener
    virtual void OnIpcResponseReceived(Tizen::Io::_IpcClient& client, const IPC::Message& message);

	result Construct(void);
	result GetImsi(Tizen::Base::String& imsi) const;
	result HasSystemPrivilege(void);
	result GetNetworkSelectionMode(_NetworkManagerImpl* pNetworkManagerImpl);
	result SelectNetwork(_NetworkManagerImpl* pNetworkManagerImpl, const Tizen::Base::String& plmn, const int netwokrType);
    result SelectNetwork(_NetworkManagerImpl* pNetworkManagerImpl);
    result SearchNetwork(_NetworkManagerImpl* pNetworkManagerImpl);

	result HasCallForwardPrivilege(void);
    result RequestCallForward(_CallManagerImpl* pCallManagerImpl, const Tizen::Base::String& phoneNumber);
    result StopCallForward(_CallManagerImpl* pCallManagerImpl);
    result GetCallForwardNumber(_CallManagerImpl* pCallManagerImpl);

    static _TelephonyIpcProxy* GetInstance(void);

private:
	_TelephonyIpcProxy(void);
	virtual ~_TelephonyIpcProxy(void);


	_TelephonyIpcProxy(const _TelephonyIpcProxy& value);
	_TelephonyIpcProxy& operator =(const _TelephonyIpcProxy& rhs);

	void OnNetworkSelectionModeReceived(bool isManual, unsigned long res);
	void OnNetworkSelectionCompleted(unsigned long res);
	void OnNetworkSearchCompleted(Tizen::Base::String message, unsigned long res);

	void OnTelephonyCallForwardNumberReceived(Tizen::Base::String phoneNumber, unsigned long res);
	void OnTelephonyCallForwardResponseReceived(Tizen::Base::String phoneNumber, unsigned long res);
	void OnTelephonyCallForwardStopped(Tizen::Base::String phoneNumber, unsigned long res);

	static void InitSingleton(void);
	
private:
	Tizen::Io::_IpcClient* __pIpcClient;
	_NetworkManagerImpl* __pNetworkManagerImplForGet;
	_NetworkManagerImpl* __pNetworkManagerImplForSelect;
	_NetworkManagerImpl* __pNetworkManagerImplForSearch;
	_CallManagerImpl* __pCallManagerImplForGet;
	_CallManagerImpl* __pCallManagerImplForStart;
	_CallManagerImpl* __pCallManagerImplForStop;
	static _TelephonyIpcProxy* __pInstance;

}; // _TelephonyIpcProxy

}}
#endif // _FNET_WIFI_INTERNAL_TELEPHONY_IPC_PROXY_H_
