//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file    FTel_TelephonyUtility.h
 * @brief   This is the header file for the %_TelephonyUtility class.
 *
 * This header file contains the declarations of the %_TelephonyUtility class.
 */

#ifndef _FTEL_INTERNAL_TELEPHONY_UTILITY_H_
#define _FTEL_INTERNAL_TELEPHONY_UTILITY_H_

#include <net_connection.h>
#include <TelNetwork.h>
#include "FTel_NetworkInfoImpl.h"

namespace Tizen { namespace Base
{
class String;
}}

namespace Tizen { namespace Telephony
{

static const int _HASH_CODE_INITIAL_VALUE = 17;
static const int _HASH_CODE_COEFFICIENT_VALUE = 37;

struct _ConnectionDeleter
{
    void operator()(void* pConnection)
    {
        connection_destroy(pConnection);
    }
};

struct _CharDeleter
{
    void operator()(char* pChar)
    {
        free(pChar);
    }
};

class _TelephonyUtility
{
public:
    /**
     * Converts TelNetworkSystemType_t to _NetworkType Type
     *
     * @return      The network type
     * @param[in]   networkSystem   network system type
     */
    static _NetworkType ConvertNetworkType(TelNetworkSystemType_t networkSystemType);

    /**
     * Converts _NetworkType to TelNetworkSystemType_t Type
     *
     * @return      The network type
     * @param[in]   networkSystem   network type
     */
    static TelNetworkSystemType_t ConvertNetworkType(_NetworkType networkType);

    static result ConvertErrorType(int error);

    static void GetMccMncFromPlmn(const Tizen::Base::String& plmn, int& mcc, int& mnc);


private:
    /**
     * This default constructor is intentionally declared as private because this class cannot be constructed.
     */
    _TelephonyUtility(void);

    /**
     * This destructor is intentionally declared as private because this class cannot be constructed.
     */
    virtual ~_TelephonyUtility(void);

}; // _TelephonyUtility

} }  // Tizen::Telephony
#endif // _FTEL_INTERNAL_TELEPHONY_UTILITY_H_

