//
// Open Service Platform
// Copyright (c) 2012-2013 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
/**
 * @file	FTel_ConnectivityIpcMessages.h
 * @brief	This is the header file for the Connectivity service daemon's IPC messages.
 *
 * This header file contains the declarations of the IPC messages for the Connectivity service daemon.
 */

#include <ipc/ipc_message_macros.h>
#include <FIo_IpcCommonParamTraits.h>
#include <FIo_IpcMessageStart.h>

#ifndef TELEPHONY_CONNECTIVITY_IPC_SERVER_NAME
#define TELEPHONY_CONNECTIVITY_IPC_SERVER_NAME "osp.telephony.ipcserver.connectivity"
#endif

#define IPC_MESSAGE_START ConnectivityTelephonyServiceMsgStart

// Client -> Server (sync)
IPC_SYNC_MESSAGE_CONTROL0_2(ConnectivityTelephonyServiceMsg_getImsi, Tizen::Base::String /* imsi */, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_hasSystemPrivilege, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_getNetworkSelectionMode, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL2_1(ConnectivityTelephonyServiceMsg_selectNetworkManual, Tizen::Base::String /* plmn */, int /* network type */, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_selectNetworkAutomatic, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_searchNetwork, unsigned long /* result */)

IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_hasCallForwardPrivilege, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL1_1(ConnectivityTelephonyServiceMsg_requestCallForward, Tizen::Base::String /* phone number */, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_stopCallForward, unsigned long /* result */)
IPC_SYNC_MESSAGE_CONTROL0_1(ConnectivityTelephonyServiceMsg_getCallForwardNumber, unsigned long /* result */)



// Server -> Client (async)
IPC_MESSAGE_CONTROL2(ConnectivityTelephonyServiceMsg_onNetworkSelectionModeReceived, bool /* isManual */, unsigned long /* result */);
IPC_MESSAGE_CONTROL1(ConnectivityTelephonyServiceMsg_onNetworkSelectionCompleted, unsigned long /* result */);
IPC_MESSAGE_CONTROL2(ConnectivityTelephonyServiceMsg_onNetworkSearchCompleted, Tizen::Base::String /* message */, unsigned long /* result */);
IPC_MESSAGE_CONTROL2(ConnectivityTelephonyServiceMsg_onCallForwardNumberReceived, Tizen::Base::String /* phone number */, unsigned long /* result */);
IPC_MESSAGE_CONTROL2(ConnectivityTelephonyServiceMsg_onCallForwardResponseReceived, Tizen::Base::String /* phone number */, unsigned long /* result */);
IPC_MESSAGE_CONTROL2(ConnectivityTelephonyServiceMsg_onCallForwardStopped, Tizen::Base::String /* phone number */, unsigned long /* result */);

